/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2019 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  19.01.2019  mifi  First Version for the SAM4E Xplained Pro board.
**************************************************************************/
#if !defined(__TALBOARD_H__) && defined(USE_BOARD_SAM4EXPRO)
#define __TALBOARD_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include "project.h"
#include "taltypes.h"
#include "heap_conf.h"

#include "sam4e.h"

/**************************************************************************
*  Global Definitions
**************************************************************************/

/*
 * Defines for board and cpu name
 */
#define TAL_BOARD "ATSAM4E-XPRO"
#define TAL_CPU   "ATSAM4E16E"


/*
 * Check OSCILLATOR_CLOCK_FREQUENCY value, must be 12MHz
 */
#if (OSCILLATOR_CLOCK_FREQUENCY != 12000000)
   Error: OSCILLATOR_CLOCK_FREQUENCY must defined to 12000000 by the preprocessor;
#endif   

 
/*
 * With 4 bits of interrupt priority 16 levels are
 * available. Priority 0 is the highest one, 15 the lowest.
 */

#ifndef SYSTICK_PRIO
#define SYSTICK_PRIO    0
#endif 

#ifndef UART0_PRIO
#define UART0_PRIO      7
#endif



/*
 * The SAM 4E Xplained Pro board support 1 LED
 */
typedef enum _tal_led_channel_
{
   TAL_LED_CHANNEL_1 = 0,
   
   /* TAL_LED_CHANNEL_MAX must be the last one */
   TAL_LED_CHANNEL_MAX
} TAL_LED_CHANNEL;

/*
 * LED name from the board itself
 */
#define LED0   TAL_LED_CHANNEL_1


/*
 * COM port used for the terminal, UART0 = PORT1
 */
#if !defined(TERM_COM_PORT)
#define TERM_COM_PORT   TAL_COM_PORT_1
#endif

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

TAL_RESULT tal_BoardEnableCOM1(void);
TAL_RESULT tal_BoardEnableCOM2(void);
TAL_RESULT tal_BoardEnableCOM3(void);
TAL_RESULT tal_BoardEnableCOM4(void);
TAL_RESULT tal_BoardEnableCOM5(void);
TAL_RESULT tal_BoardEnableCOM6(void);

#endif /* !__TALBOARD_H__ */

/*** EOF ***/
